import greenfoot.*;

/**
 * A main actor to be passed from world to world.  The Text objects defined, created
 * and added to the world will stay with this object by the 'addedToWorld' method.
 */
public class Kara extends Actor
{
    private int distance, score; // values to be displayed by the following Text objects
    private Text moveText, scoreText; // objects to display the previous field values
    
    // create the Text objects when this object is created
    public Kara()
    {
        getImage().scale(25, 25);
        moveText = new Text("Distance: 0");
        scoreText = new Text("Score: 0");
    }
    
    // this method adds the Text objects into any world that this actor is added or moved into
    public void addedToWorld(World w)
    {
        w.addObject(moveText, 100, 20);
        w.addObject(scoreText, Level.worldWidth-100, 20);
        // if landing on a door, inform door not to trigger world changing until moved off it
        Door door = (Door)getOneIntersectingObject(Door.class);
        if (door != null) door.foundOff = false;
    }

    // check movement and track distance
    public void act()
    {
        if (Greenfoot.isKeyDown("space")) getWorld().getBackground().setColorAt(getX(), getY(), Color.BLACK);
        //*******************************************************
        // check position change
        int dx = 0, dy = 0;
        if (Greenfoot.isKeyDown("right")) dx++;
        if (Greenfoot.isKeyDown("left")) dx--;
        if (Greenfoot.isKeyDown("down")) dy++;
        if (Greenfoot.isKeyDown("up")) dy--;
        if (dx == 0 && dy == 0) return;
        // change position
        setLocation(getX()+dx, getY()+dy);
        // set proper rotation for direction of movement (don't ask -- ok, if you must)
        setRotation((90-90*dx)*dx*dx*(1-dy*dy)+(90*dy)*dy*dy*(1-dx*dx)+(135-90*dx)*dx*dy);
        // adjust Text object value(s)
        distance++;
        if (distance%40 == 0)
        {
            moveText.setText("Distance: "+distance/40);
            adjustScore(1);
        }
    }
    
    // adds adjustment to score and updates the displaying of score
    // (public method needed for this because the Door class adds eight to the score when changing worlds)
    public void adjustScore(int amt)
    {
        score += amt;
        scoreText.setText("Score: "+score);
    }
}